==> pf4-component-mapper-3.23.0.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "container", "inModal"],
    _excluded2 = ["inModal", "title", "description", "buttonLabels", "buttonsClassName", "showTitles", "container", "hideClose", "titleId", "descriptionId", "closeButtonAriaLabel", "hasNoBodyPadding", "navAriaLabel", "StepTemplate", "className", "conditionalSubmitFlag", "ModalProps"],
    _excluded3 = ["buttonLabels"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useReducer, useEffect, useContext } from 'react';
import PropTypes from 'prop-types';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import Wizard from '@data-driven-forms/common/wizard/wizard';
import { WizardNav } from "@patternfly/react-core/dist/dynamic/components/Wizard";
import { WizardHeader } from "@patternfly/react-core/dist/dynamic/components/Wizard";
import { Modal as PF4Modal } from "@patternfly/react-core/dist/dynamic/components/Modal";
import WizardStep from './wizard-components/wizard-step';
import './wizard-components/wizard-styles.css';
import WizardNavigation from './wizard-components/wizard-nav';
import reducer from './wizard-components/reducer';
import WizardToggle from './wizard-components/wizard-toggle';

var Modal = function Modal(_ref) {
  var children = _ref.children,
      container = _ref.container,
      inModal = _ref.inModal,
      rest = _objectWithoutProperties(_ref, _excluded);

  return inModal ? /*#__PURE__*/React.createElement(PF4Modal, _extends({
    variant: "large",
    isOpen: true,
    showClose: false,
    hasNoBodyWrapper: true,
    appendTo: container
  }, rest), children) : children;
};

Modal.propTypes = {
  children: PropTypes.node,
  container: PropTypes.instanceOf(Element),
  inModal: PropTypes.bool
};

var WizardInternal = function WizardInternal(_ref2) {
  var inModal = _ref2.inModal,
      title = _ref2.title,
      description = _ref2.description,
      buttonLabels = _ref2.buttonLabels,
      buttonsClassName = _ref2.buttonsClassName,
      showTitles = _ref2.showTitles,
      container = _ref2.container,
      hideClose = _ref2.hideClose,
      titleId = _ref2.titleId,
      descriptionId = _ref2.descriptionId,
      closeButtonAriaLabel = _ref2.closeButtonAriaLabel,
      hasNoBodyPadding = _ref2.hasNoBodyPadding,
      navAriaLabel = _ref2.navAriaLabel,
      StepTemplate = _ref2.StepTemplate,
      className = _ref2.className,
      conditionalSubmitFlag = _ref2.conditionalSubmitFlag,
      _ref2$ModalProps = _ref2.ModalProps,
      ModalProps = _ref2$ModalProps === void 0 ? {} : _ref2$ModalProps,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  var _useContext = useContext(WizardContext),
      crossroads = _useContext.crossroads,
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      _onKeyDown = _useContext.onKeyDown,
      _jumpToStep = _useContext.jumpToStep,
      setPrevSteps = _useContext.setPrevSteps,
      _handleNext = _useContext.handleNext,
      navSchema = _useContext.navSchema,
      activeStepIndex = _useContext.activeStepIndex,
      maxStepIndex = _useContext.maxStepIndex,
      isDynamic = _useContext.isDynamic;

  var _useReducer = useReducer(reducer, {
    loading: true,
    container: container,
    openNav: false
  }),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  useEffect(function () {
    if (inModal) {
      dispatch({
        type: 'setContainer'
      });
    } else {
      dispatch({
        type: 'finishLoading'
      });
    }
  }, [inModal]);
  useEffect(function () {
    if (ModalProps.appendTo) {
      // override with default append to
      dispatch({
        type: 'finishLoading'
      });
    } else if (state.container) {
      document.body.appendChild(state.container);
      dispatch({
        type: 'finishLoading'
      });
    }

    return function () {
      if (inModal && state.container) {
        document.body.removeChild(state.container);
      }
    };
  }, [state.container, inModal]);

  if (state.loading) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Modal, _extends({
    inModal: inModal,
    container: state.container,
    "aria-labelledby": rest.name
  }, ModalProps, {
    className: inModal ? "pf-v5-c-form".concat(ModalProps.className || '') : ModalProps.className
  }), /*#__PURE__*/React.createElement("div", _extends({
    tabIndex: inModal ? 0 : null,
    className: "pf-v5-c-wizard ".concat(inModal ? '' : 'no-shadow', " ddorg__pf4-component-mapper__wizard ").concat(className ? className : ''),
    role: "dialog",
    "aria-modal": inModal ? 'true' : undefined,
    onKeyDown: function onKeyDown(e) {
      _onKeyDown(e);

      if (e.key === 'Escape' && inModal) {
        formOptions.onCancel();
      }
    }
  }, rest), title && /*#__PURE__*/React.createElement(WizardHeader, {
    title: title,
    description: description,
    onClose: formOptions.onCancel,
    isCloseHidden: hideClose,
    titleId: titleId,
    descriptionId: descriptionId,
    closeButtonAriaLabel: closeButtonAriaLabel
  }), /*#__PURE__*/React.createElement(WizardToggle, {
    activeStepIndex: activeStepIndex,
    currentStep: currentStep,
    navSchema: navSchema,
    isOpen: state.openNav,
    dispatch: dispatch
  }), /*#__PURE__*/React.createElement("div", {
    className: "pf-v5-c-wizard__outer-wrap"
  }, /*#__PURE__*/React.createElement("div", {
    className: "pf-v5-c-wizard__inner-wrap"
  }, /*#__PURE__*/React.createElement(WizardNav, {
    "aria-label": navAriaLabel,
    isExpanded: state.openNav
  }, /*#__PURE__*/React.createElement(FormSpy, {
    subscription: {
      values: true,
      valid: true,
      validating: true
    }
  }, function (_ref3) {
    var values = _ref3.values,
        valid = _ref3.valid,
        validating = _ref3.validating;
    return /*#__PURE__*/React.createElement(WizardNavigation, {
      navSchema: navSchema,
      activeStepIndex: activeStepIndex,
      valid: valid,
      maxStepIndex: maxStepIndex,
      jumpToStep: function jumpToStep() {
        state.openNav && dispatch({
          type: 'closeNav'
        });
        return _jumpToStep.apply(void 0, arguments);
      },
      crossroads: crossroads,
      isDynamic: isDynamic,
      values: values,
      setPrevSteps: setPrevSteps,
      validating: validating
    });
  })), /*#__PURE__*/React.createElement(WizardStep, _extends({
    conditionalSubmitFlag: conditionalSubmitFlag,
    buttonLabels: buttonLabels,
    buttonsClassName: buttonsClassName,
    showTitles: showTitles,
    hasNoBodyPadding: hasNoBodyPadding,
    StepTemplate: StepTemplate
  }, currentStep, {
    formOptions: formOptions,
    handleNext: function handleNext(nextStep) {
      return _handleNext(nextStep);
    },
    handlePrev: handlePrev,
    disableBack: activeStepIndex === 0
  }))))));
};

WizardInternal.propTypes = {
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node.isRequired,
    cancel: PropTypes.node.isRequired,
    back: PropTypes.node.isRequired,
    next: PropTypes.node.isRequired
  }).isRequired,
  buttonsClassName: PropTypes.string,
  title: PropTypes.any,
  description: PropTypes.any,
  inModal: PropTypes.bool,
  showTitles: PropTypes.bool,
  hideClose: PropTypes.bool,
  titleId: PropTypes.string,
  descriptionId: PropTypes.string,
  closeButtonAriaLabel: PropTypes.string,
  hasNoBodyPadding: PropTypes.bool,
  navAriaLabel: PropTypes.string,
  container: PropTypes.instanceOf(Element),
  StepTemplate: PropTypes.elementType,
  className: PropTypes.string,
  conditionalSubmitFlag: PropTypes.string,
  ModalProps: PropTypes.object
};
var defaultLabels = {
  submit: 'Submit',
  cancel: 'Cancel',
  back: 'Back',
  next: 'Next'
};

var WizardFunction = function WizardFunction(_ref4) {
  var _ref4$buttonLabels = _ref4.buttonLabels,
      buttonLabels = _ref4$buttonLabels === void 0 ? {} : _ref4$buttonLabels,
      props = _objectWithoutProperties(_ref4, _excluded3);

  return /*#__PURE__*/React.createElement(Wizard, _extends({
    Wizard: WizardInternal
  }, props, {
    buttonLabels: _objectSpread(_objectSpread({}, defaultLabels), buttonLabels)
  }));
};

WizardFunction.propTypes = {
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node,
    cancel: PropTypes.node,
    back: PropTypes.node
  })
};
export default WizardFunction;

==> pf4-component-mapper-4.0.0.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "container", "inModal"],
    _excluded2 = ["inModal", "title", "description", "buttonLabels", "buttonsClassName", "showTitles", "container", "hideClose", "titleId", "descriptionId", "closeButtonAriaLabel", "hasNoBodyPadding", "navAriaLabel", "StepTemplate", "className", "conditionalSubmitFlag", "ModalProps"],
    _excluded3 = ["buttonLabels"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useReducer, useEffect, useContext } from 'react';
import PropTypes from 'prop-types';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import Wizard from '@data-driven-forms/common/wizard/wizard';
import { WizardNav } from "@patternfly/react-core/dist/dynamic/components/Wizard";
import { WizardHeader } from "@patternfly/react-core/dist/dynamic/components/Wizard";
import { Modal as PF4Modal } from '@patternfly/react-core/deprecated';
import WizardStep from './wizard-components/wizard-step';
import './wizard-components/wizard-styles.css';
import WizardNavigation from './wizard-components/wizard-nav';
import reducer from './wizard-components/reducer';
import WizardToggle from './wizard-components/wizard-toggle';

var Modal = function Modal(_ref) {
  var children = _ref.children,
      container = _ref.container,
      inModal = _ref.inModal,
      rest = _objectWithoutProperties(_ref, _excluded);

  return inModal ? /*#__PURE__*/React.createElement(PF4Modal, _extends({
    variant: "large",
    isOpen: true,
    showClose: false,
    hasNoBodyWrapper: true,
    appendTo: container
  }, rest), children) : children;
};

Modal.propTypes = {
  children: PropTypes.node,
  container: PropTypes.instanceOf(Element),
  inModal: PropTypes.bool
};

var WizardInternal = function WizardInternal(_ref2) {
  var inModal = _ref2.inModal,
      title = _ref2.title,
      description = _ref2.description,
      buttonLabels = _ref2.buttonLabels,
      buttonsClassName = _ref2.buttonsClassName,
      showTitles = _ref2.showTitles,
      container = _ref2.container,
      hideClose = _ref2.hideClose,
      titleId = _ref2.titleId,
      descriptionId = _ref2.descriptionId,
      closeButtonAriaLabel = _ref2.closeButtonAriaLabel,
      hasNoBodyPadding = _ref2.hasNoBodyPadding,
      navAriaLabel = _ref2.navAriaLabel,
      StepTemplate = _ref2.StepTemplate,
      className = _ref2.className,
      conditionalSubmitFlag = _ref2.conditionalSubmitFlag,
      _ref2$ModalProps = _ref2.ModalProps,
      ModalProps = _ref2$ModalProps === void 0 ? {} : _ref2$ModalProps,
      rest = _objectWithoutProperties(_ref2, _excluded2);

  var _useContext = useContext(WizardContext),
      crossroads = _useContext.crossroads,
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      _onKeyDown = _useContext.onKeyDown,
      _jumpToStep = _useContext.jumpToStep,
      setPrevSteps = _useContext.setPrevSteps,
      _handleNext = _useContext.handleNext,
      navSchema = _useContext.navSchema,
      activeStepIndex = _useContext.activeStepIndex,
      maxStepIndex = _useContext.maxStepIndex,
      isDynamic = _useContext.isDynamic;

  var _useReducer = useReducer(reducer, {
    loading: true,
    container: container,
    openNav: false
  }),
      _useReducer2 = _slicedToArray(_useReducer, 2),
      state = _useReducer2[0],
      dispatch = _useReducer2[1];

  useEffect(function () {
    if (inModal) {
      dispatch({
        type: 'setContainer'
      });
    } else {
      dispatch({
        type: 'finishLoading'
      });
    }
  }, [inModal]);
  useEffect(function () {
    if (ModalProps.appendTo) {
      // override with default append to
      dispatch({
        type: 'finishLoading'
      });
    } else if (state.container) {
      document.body.appendChild(state.container);
      dispatch({
        type: 'finishLoading'
      });
    }

    return function () {
      if (inModal && state.container) {
        document.body.removeChild(state.container);
      }
    };
  }, [state.container, inModal]);

  if (state.loading) {
    return null;
  }

  return /*#__PURE__*/React.createElement(Modal, _extends({
    inModal: inModal,
    container: state.container,
    "aria-labelledby": rest.name
  }, ModalProps, {
    className: inModal ? "pf-v6-c-form".concat(ModalProps.className || '') : ModalProps.className
  }), /*#__PURE__*/React.createElement("div", _extends({
    tabIndex: inModal ? 0 : null,
    className: "pf-v6-c-wizard ".concat(inModal ? '' : 'no-shadow', " ddorg__pf4-component-mapper__wizard ").concat(className ? className : ''),
    role: "dialog",
    "aria-modal": inModal ? 'true' : undefined,
    onKeyDown: function onKeyDown(e) {
      _onKeyDown(e);

      if (e.key === 'Escape' && inModal) {
        formOptions.onCancel();
      }
    }
  }, rest), title && /*#__PURE__*/React.createElement(WizardHeader, {
    title: title,
    description: description,
    onClose: formOptions.onCancel,
    isCloseHidden: hideClose,
    titleId: titleId,
    descriptionId: descriptionId,
    closeButtonAriaLabel: closeButtonAriaLabel
  }), /*#__PURE__*/React.createElement(WizardToggle, {
    activeStepIndex: activeStepIndex,
    currentStep: currentStep,
    navSchema: navSchema,
    isOpen: state.openNav,
    dispatch: dispatch
  }), /*#__PURE__*/React.createElement("div", {
    className: "pf-v6-c-wizard__outer-wrap"
  }, /*#__PURE__*/React.createElement("div", {
    className: "pf-v6-c-wizard__inner-wrap"
  }, /*#__PURE__*/React.createElement(WizardNav, {
    "aria-label": navAriaLabel,
    isExpanded: state.openNav
  }, /*#__PURE__*/React.createElement(FormSpy, {
    subscription: {
      values: true,
      valid: true,
      validating: true
    }
  }, function (_ref3) {
    var values = _ref3.values,
        valid = _ref3.valid,
        validating = _ref3.validating;
    return /*#__PURE__*/React.createElement(WizardNavigation, {
      navSchema: navSchema,
      activeStepIndex: activeStepIndex,
      valid: valid,
      maxStepIndex: maxStepIndex,
      jumpToStep: function jumpToStep() {
        state.openNav && dispatch({
          type: 'closeNav'
        });
        return _jumpToStep.apply(void 0, arguments);
      },
      crossroads: crossroads,
      isDynamic: isDynamic,
      values: values,
      setPrevSteps: setPrevSteps,
      validating: validating
    });
  })), /*#__PURE__*/React.createElement(WizardStep, _extends({
    conditionalSubmitFlag: conditionalSubmitFlag,
    buttonLabels: buttonLabels,
    buttonsClassName: buttonsClassName,
    showTitles: showTitles,
    hasNoBodyPadding: hasNoBodyPadding,
    StepTemplate: StepTemplate
  }, currentStep, {
    formOptions: formOptions,
    handleNext: function handleNext(nextStep) {
      return _handleNext(nextStep);
    },
    handlePrev: handlePrev,
    disableBack: activeStepIndex === 0
  }))))));
};

WizardInternal.propTypes = {
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node.isRequired,
    cancel: PropTypes.node.isRequired,
    back: PropTypes.node.isRequired,
    next: PropTypes.node.isRequired
  }).isRequired,
  buttonsClassName: PropTypes.string,
  title: PropTypes.any,
  description: PropTypes.any,
  inModal: PropTypes.bool,
  showTitles: PropTypes.bool,
  hideClose: PropTypes.bool,
  titleId: PropTypes.string,
  descriptionId: PropTypes.string,
  closeButtonAriaLabel: PropTypes.string,
  hasNoBodyPadding: PropTypes.bool,
  navAriaLabel: PropTypes.string,
  container: PropTypes.instanceOf(Element),
  StepTemplate: PropTypes.elementType,
  className: PropTypes.string,
  conditionalSubmitFlag: PropTypes.string,
  ModalProps: PropTypes.object
};
var defaultLabels = {
  submit: 'Submit',
  cancel: 'Cancel',
  back: 'Back',
  next: 'Next'
};

var WizardFunction = function WizardFunction(_ref4) {
  var _ref4$buttonLabels = _ref4.buttonLabels,
      buttonLabels = _ref4$buttonLabels === void 0 ? {} : _ref4$buttonLabels,
      props = _objectWithoutProperties(_ref4, _excluded3);

  return /*#__PURE__*/React.createElement(Wizard, _extends({
    Wizard: WizardInternal
  }, props, {
    buttonLabels: _objectSpread(_objectSpread({}, defaultLabels), buttonLabels)
  }));
};

WizardFunction.propTypes = {
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node,
    cancel: PropTypes.node,
    back: PropTypes.node
  })
};
export default WizardFunction;
